package org.sourceforge.jbezier.Examples;

//This example requires LWJGL!!

import static org.lwjgl.opengl.GL11.*;
import org.lwjgl.opengl.*;
import org.lwjgl.*;
import org.sourceforge.jbezier.*;

public class SimpleExample {
	
	private JBezier bezier;
	private Point[] userPoints;  //These are the points that we use to generate the bzier curve with (connected with red lines)
	private Point[] bezierPoints; //These are the points that make up the bzier curve
	
	public SimpleExample(){
		try{
			Display.setDisplayMode(new DisplayMode(800,600));
			Display.setTitle("Bzier Example #1 Simple renderer");
			Display.create();
		}catch(LWJGLException e){
			e.printStackTrace();
		}
		
		//init code for opengl
		glMatrixMode(GL_PROJECTION);
		glLoadIdentity();
		glOrtho(0, 800, 600, 0, 1, -1);
		glMatrixMode(GL_MODELVIEW);
		
		glEnable(GL_POINT_SMOOTH);
		glHint(GL_POINT_SMOOTH_HINT, GL_NICEST);
		
		userPoints = new Point[]{ //We create four new Points
				new Point(100, 500),
				new Point(130, 100),
				new Point(400, 50),
				new Point(700, 500)
		};
		
		bezier = new JBezier(3, 2000, userPoints); //The Points are now given to the JBezier class, and we say
												   //that we need 2000 iterations, so we will receive 2000 points,
												   //also we say that the order should be three, since we have four points
		bezierPoints = bezier.generateBezier();    //now we calculate the bzier curve
		
		while(!Display.isCloseRequested()){
			//render
			glClear(GL_COLOR_BUFFER_BIT);
			
			
			//Now we connect our 4 points with red lines
			glColor3f(1f,0f,0f);
			glBegin(GL_LINES);
			for(int i = 0; i < userPoints.length-1; i++){
				glVertex2d(userPoints[i].x, userPoints[i].y);
				glVertex2d(userPoints[i+1].x, userPoints[i+1].y);
			}
			glEnd();
			
			
			//This is the actual drawing of the bzier curve
			glColor3f(1f, 1f, 1f);
			glBegin(GL_POINTS);
			for(int i = 0; i < bezierPoints.length; i++){
				glVertex2d(bezierPoints[i].x, bezierPoints[i].y);
			}
			glEnd();
			
			
			
			Display.update();
			Display.sync(60);
		}
		
		Display.destroy();
	}

	public static void main(String[] args) {
		new SimpleExample();
	}

}